@@ -1,12 +1,14 @@
-#' @title LCC_Significance
+#' LCC Significance
 #' @description Calculates the Largest Connected Component (LCC) from a given graph, and calculates its significance using a degree preserving approach.
 #' Menche, J., et al (2015) <doi.org:10.1126/science.1065103>
+#'
 #' @param N Number of randomizations.
 #' @param Targets Name of the nodes that the subgraph will focus on - Those are the nodes you want to know whether if forms an LCC.
 #' @param G The  graph of interest (often, in NetMed it is an interactome - PPI).
-#' @param bins the number os bins for the degree preserving randomization.
+#' @param bins the number os bins for the degree preserving randomization. When bins = 1, assumes a uniform distribution for nodes.
 #' @param min_per_bin the minimum size of each bin.
 #' @param hypothesis are you expecting an LCC greater or smaller than the average?
+#'
 #' @importFrom graphics abline hist title
 #' @importFrom stats ecdf sd
 #' @importFrom magrittr `%>%` `%<>%`
@@ -17,7 +19,8 @@
 #' - $sd the sd LCC of the randomizations
 #' - $Z The score
 #' - $LCC the LCC of the given targets
-#' - $emp\_p the empirical p-value for the LCC
+#' - $emp_p the empirical p-value for the LCC
+#' - $rLCC the relative LCC
 #'
 #' @export
 #'
@@ -33,15 +36,17 @@
 #' g <- igraph::graph_from_data_frame(net, directed = FALSE )
 #' plot(g)
 #' targets = c("I", "H", "F", "E")
-#' LCC_Significance(N = 100,
-#'                  Targets = targets,
-#'                                   G = g,
-#'                                   bins = 5,
+#'  LCC_Significance(N = 100,
+#'                    Targets = targets,
+#'                                     G = g,
+#'                                   bins = 1,
 #'                                   min_per_bin = 2)
-#'                                   # in a real interactome, please use the default
+#'
 #'
 
-LCC_Significance = function(N = N, Targets = Targets, G, bins =100, hypothesis = "greater", min_per_bin = 20){
+LCC_Significance = function(N = N, Targets = Targets, G,
+                            bins =100, hypothesis = "greater",
+                            min_per_bin = 20){
   LCC_1 = LCC_number(G, Targets)
   Vn = Targets
   LCC_total = LCC_1
@@ -66,5 +71,6 @@ LCC_Significance = function(N = N, Targets = Targets, G, bins =100, hypothesis =
               sd = sdC,
               Z= Z,
               LCC = LCC_1,
-              emp_p = p))
+              emp_p = p,
+              rLCC = LCC_1/length(Targets)))
 }
